@@ -262,9 +262,9 @@ g_win32_get_package_installation_directory_of_module (gpointer hmodule)
   {
     gchar tmp[MAX_PATH];
 
-    cygwin_conv_to_posix_path(fn, tmp);
-    g_free(fn);
-    fn = g_strdup(tmp);
+    cygwin_conv_to_posix_path (retval, tmp);
+    g_free (retval);
+    retval = g_strdup (tmp);
   }
 #endif
 
@@ -442,6 +442,8 @@ g_win32_get_package_installation_directory (const gchar *package,
   return result;
 }
 
+#if !defined (_WIN64)
+
 #undef g_win32_get_package_installation_directory
 
 /* DLL ABI binary compatibility version that uses system codepage file names */
@@ -472,6 +474,8 @@ g_win32_get_package_installation_directory (const gchar *package,
   return retval;
 }
 
+#endif
+
 /**
  * g_win32_get_package_installation_subdirectory:
  * @package: You should pass %NULL for this.
@@ -512,6 +516,8 @@ g_win32_get_package_installation_subdirectory (const gchar *package,
   return dirname;
 }
 
+#if !defined (_WIN64)
+
 #undef g_win32_get_package_installation_subdirectory
 
 /* DLL ABI binary compatibility version that uses system codepage file names */
@@ -532,6 +538,8 @@ g_win32_get_package_installation_subdirectory (const gchar *package,
   return dirname;
 }
 
+#endif
+
 static guint windows_version;
 
 static void 
